@@ -33,9 +33,10 @@
 #  define KIDLETIME_DEPRECATED_NO_EXPORT KIDLETIME_NO_EXPORT KIDLETIME_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KIDLETIME_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KIDLETIME_NO_DEPRECATED
+#    define KIDLETIME_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
